@@ -1,9 +1,14 @@
 #!/usr/bin/env python2
 
-import math, sys
-import inkex
+from __future__ import print_function
 
-inkex.localize()
+import math, sys
+
+if sys.version_info[0] >= 3:
+    unicode = lambda s, enc: s.decode(enc) if isinstance(s, bytes) else s
+
+import inkex
+from simpletransform import computePointInNode
 
 #QRCode for Python
 #
@@ -972,7 +977,7 @@ class QRRSBlock:
         if rsBlock == None:
             raise Exception("bad rs block @ typeNumber:" + typeNumber + "/errorCorrectLevel:" + errorCorrectLevel)
 
-        length = len(rsBlock) / 3
+        length = len(rsBlock) // 3
 
         list = []
 
@@ -1009,7 +1014,7 @@ class QRBitBuffer:
     def get(self, index):
         bufIndex = math.floor(index / 8)
         val = ( (self.buffer[bufIndex] >> (7 - index % 8) ) & 1) == 1
-        print "get ", val
+        print("get ", val)
         return ( (self.buffer[bufIndex] >> (7 - index % 8) ) & 1) == 1
     def put(self, num, length):
         for i in range(length):
@@ -1057,7 +1062,7 @@ class QRCodeInkscape(inkex.Effect):
             #INKSCAPE GROUP TO CONTAIN EVERYTHING
             
             so.TEXT = unicode(so.TEXT, so.input_encode)
-            centre = self.view_center   #Put in in the centre of the current view
+            centre = tuple(computePointInNode(list(self.view_center), self.current_layer))   #Put in in the centre of the current view
             grp_transform = 'translate' + str( centre ) + ' scale(%f)' % scale
             grp_name = 'QR Code: '+so.TEXT
             grp_attribs = {inkex.addNS('label','inkscape'):grp_name,
